@@ -6,8 +6,8 @@ from .model import Model
 
 def Column(
     sqltype: TypeEngine,
-    primary_key: bool = False,
-    nullable: bool = False,
+    primary_key: bool = None,
+    nullable: bool = None,
 ): pass
 
 
